@@ -189,177 +189,12 @@ static TokenTable aTokTable_Basic [] = {		// Token-Tabelle:
     { NIL,		"" }
 };
 
-/*
-TokenTable aTokTable_Java [] = {		// Token-Tabelle:
-
-    { JS_LOG_NOT,	"!" },
-    { JS_NE,		"!=" },
-    { JS_MOD,		"%" },
-    { JS_ASS_MOD,	"%=" },
-    { JS_BIT_AND,	"&" },
-    { JS_LOG_AND,	"&&" },
-    { JS_ASS_AND,	"&=" },
-    { JS_LPAREN,	"(" },
-    { JS_RPAREN,	")" },
-    { JS_MUL,		"*" },
-    { JS_ASS_MUL,	"*=" },
-    { JS_PLUS,		"+" },
-    { JS_INC,		"++" },
-    { JS_ASS_PLUS,	"+=" },
-    { JS_COMMA,		"," },
-    { JS_MINUS,		"-" },
-    { JS_DEC,		"--" },
-    { JS_ASS_MINUS,	"-=" },
-    { JS_DIV,		"/" },
-    { JS_ASS_DIV,	"/=" },
-    { JS_COND_SEL,	":" },
-    { JS_LT,		"<" },
-    { JS_LSHIFT,	"<<" },
-    { JS_ASS_LSHIFT,"<<=" },
-    { JS_LE,		"<=" },
-    { JS_NE,		"<>" },
-    { JS_ASSIGNMENT,"=" },
-    { JS_EQ,		"==" },
-    { JS_GT,		">" },
-    { JS_RSHIFT,	">>" },
-    { JS_ASS_RSHIFT,">>=" },
-    { JS_RSHIFT_Z,	">>>" },
-    { JS_ASS_RSHIFT_Z,">>>=" },
-    { JS_GE,		">=" },
-    { JS_COND_QUEST,"?" },
-    { ACCESS,	"Access" },
-    { ALIAS,	"Alias" },
-    { AND,		"And" },
-    { ANY,		"Any" },
-    { APPEND,	"Append" },
-    { AS,		"As" },
-    { BASE,		"Base" },
-    { BINARY,	"Binary" },
-    { TBOOLEAN,	"Boolean" },
-    { BYVAL,	"ByVal", },
-    { CALL,		"Call" },
-    { CASE,		"Case" },
-    { _CDECL_,	"Cdecl" },
-    { CLOSE,	"Close" },
-    { COMPARE,	"Compare" },
-    { _CONST_,	"Const" },
-    { TCURRENCY,"Currency" },
-    { TDATE,	"Date" },
-    { DECLARE,	"Declare" },
-    { DEFBOOL,	"DefBool" },
-    { DEFCUR,	"DefCur" },
-    { DEFDATE,	"DefDate" },
-    { DEFDBL,	"DefDbl" },
-    { DEFERR,	"DefErr" },
-    { DEFINT,	"DefInt" },
-    { DEFLNG,	"DefLng" },
-    { DEFOBJ,	"DefObj" },
-    { DEFSNG,	"DefSng" },
-    { DEFSTR,	"DefStr" },
-    { DEFVAR,	"DefVar" },
-    { DIM,		"Dim" },
-    { DO,		"Do" },
-    { TDOUBLE,	"Double" },
-    { EACH,		"Each" },
-    { ELSE,		"Else" },
-    { ELSEIF,	"ElseIf" },
-    { END,		"End" },
-    { ENDFUNC,	"End Function" },
-    { ENDIF,	"End If" },
-    { ENDSELECT,"End Select" },
-    { ENDSUB,	"End Sub" },
-    { ENDTYPE,	"End Type" },
-    { ENDIF,	"EndIf" },
-    { EQV,		"Eqv" },
-    { ERASE,	"Erase" },
-    { _ERROR_,	"Error" },
-    { EXIT,		"Exit" },
-    { EXPLICIT,	"Explicit" },
-    { FOR,		"For" },
-    { FUNCTION,	"Function" },
-    { GLOBAL,	"Global" },
-    { GOSUB,	"GoSub" },
-    { GOTO,		"GoTo" },
-    { IF,		"If" },
-    { IMP,		"Imp" },
-    { _IN_,		"In" },
-    { INPUT,	"Input" },				// auch INPUT #
-    { TINTEGER,	"Integer" },
-    { IS,		"Is" },
-    { LET,		"Let" },
-    { LIB,		"Lib" },
-    { LINE,		"Line" },
-    { LINEINPUT,"Line Input" },
-    { LOCAL,	"Local" },
-    { LOCK,		"Lock" },
-    { TLONG,	"Long" },
-    { LOOP,		"Loop" },
-    { LPRINT,	"LPrint" },
-    { LSET,     "LSet" }, // JSM
-    { MOD,		"Mod" },
-    { NAME,		"Name" },
-    { NEW,		"New" },
-    { NEXT,		"Next" },
-    { NOT,		"Not" },
-    { TOBJECT,	"Object" },
-    { ON,		"On" },
-    { OPEN,		"Open" },
-    { OPTION,	"Option" },
-    { _OPTIONAL_,	"Optional" },
-    { OR,		"Or" },
-    { OUTPUT,	"Output" },
-    { PRESERVE, "Preserve" },
-    { PRINT,	"Print" },
-    { PRIVATE,	"Private" },
-    { PUBLIC,	"Public" },
-    { RANDOM,	"Random" },
-    { READ,		"Read" },
-    { REDIM,	"ReDim" },
-    { REM, 		"Rem" },
-    { RESUME,	"Resume" },
-    { RETURN,	"Return" },
-    { RSET,     "RSet" }, // JSM
-    { SELECT,	"Select" },
-    { SET,		"Set" },
-    { SHARED,	"Shared" },
-    { TSINGLE,	"Single" },
-    { STATIC,	"Static" },
-    { STEP,		"Step" },
-    { STOP,		"Stop" },
-    { TSTRING,	"String" },
-    { SUB,		"Sub" },
-    { STOP,		"System" },
-    { TEXT,		"Text" },
-    { THEN,		"Then" },
-    { TO,		"To", },
-    { TYPE,		"Type" },
-    { UNTIL,	"Until" },
-    { TVARIANT,	"Variant" },
-    { WEND,		"Wend" },
-    { WHILE,	"While" },
-    { WITH,		"With" },
-    { WRITE,	"Write" },				// auch WRITE #
-    { XOR,		"Xor" },
-    { JS_LINDEX,	"[" },
-    { JS_RINDEX,	"]" },
-    { JS_BIT_XOR,	"^" },
-    { JS_ASS_XOR,	"^=" },
-    { JS_BIT_OR,	"|" },
-    { JS_ASS_OR,	"|=" },
-    { JS_LOG_OR,	"||" },
-    { JS_BIT_NOT,	"~" },
-    { NIL }
-};
-*/
-
 // Der Konstruktor ermittelt die Laenge der Token-Tabelle.
 
 SbiTokenizer::SbiTokenizer( const ::rtl::OUString& rSrc, StarBASIC* pb )
            : SbiScanner( rSrc, pb )
 {
     pTokTable = aTokTable_Basic;
-    //if( StarBASIC::GetGlobalLanguageMode() == SB_LANG_JAVASCRIPT )
-    //	pTokTable = aTokTable_Java;
     TokenTable *tp;
     bEof = bAs = FALSE;
     eCurTok = NIL;
