@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
@@ -44,7 +42,7 @@
 
 // INCLUDE ---------------------------------------------------------------
 
-#include <tools/solar.h>
+#include <bf_svtools/bf_solar.h>
 #include <string.h>
 #include <math.h>
 
@@ -191,10 +189,10 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 	bDetectCat		(rPivot.bDetectCat),
 /*N*/ 	bMakeTotalCol	(rPivot.bMakeTotalCol),
 /*N*/ 	bMakeTotalRow	(rPivot.bMakeTotalRow),
-/*N*/ 	nColNameCount	(0),
-/*N*/ 	pColNames		(NULL),
 /*N*/ 	aName			(rPivot.aName),
 /*N*/ 	aTag			(rPivot.aTag),
+/*N*/ 	nColNameCount	(0),
+/*N*/ 	pColNames		(NULL),
 /*N*/ 	nSrcCol1		(rPivot.nSrcCol1),
 /*N*/ 	nSrcRow1		(rPivot.nSrcRow1),
 /*N*/ 	nSrcCol2		(rPivot.nSrcCol2),
@@ -816,7 +814,7 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 					if (!(pDataList->AtInsert(pDataList->GetCount(), pStrData)))
 /*N*/ 					{
 /*?*/ 						delete pStrData;
-/*?*/ 						DBG_ERROR("Fehler bei pDataList->AtInsert");
+/*?*/ 						OSL_FAIL("Fehler bei pDataList->AtInsert");
 /*N*/ 					}
 /*N*/ 
 /*N*/ 					++nDataCount;
@@ -832,11 +830,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 
 /*N*/ void ScPivot::GetDataFields(PivotField* pFieldArr, short& rCount) const
 /*N*/ {
-/*	for (short i=0; i<nDataCount; i++)
-        pFieldArr[i] = aDataArr[i];
-    rCount = nDataCount;
-*/
-/*N*/ 
 /*N*/ 	rCount = 0;
 /*N*/ 	for (short i=0; i<nDataCount; i++)
 /*N*/ 	{
@@ -862,10 +855,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 
 /*N*/ BOOL ScPivot::CreateData(BOOL bKeepDest)
 /*N*/ {
-/*N*/ 	//
-/*N*/ 	//
-/*N*/ 	//
-/*N*/ 
 /*N*/ 	USHORT nOldCol2 = nDestCol2;
 /*N*/ 	USHORT nOldRow2 = nDestRow2;
 /*N*/ 
@@ -941,11 +930,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 	pColRef = NULL;
 /*N*/ }
 
-
-
-
-
-
 //--------------------------------------------------------------------------------------------------
 // Private Methoden
 //--------------------------------------------------------------------------------------------------
@@ -990,7 +974,7 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 		BOOL bValidLine = TRUE;
 /*N*/ 		if (bIgnoreEmpty)
 /*N*/ 		{
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 aSrcAdr.SetRow( nRow );
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		if (bValidLine)
 /*N*/ 			bValidLine = pDoc->pTab[nSrcTab]->ValidQuery(nRow, aQuery);
@@ -1055,7 +1039,7 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 		BOOL bValidLine = TRUE;
 /*N*/ 		if (bIgnoreEmpty)
 /*N*/ 		{
-/*?*/ 			DBG_BF_ASSERT(0, "STRIP"); //STRIP001 aSrcAdr.SetRow( nRow );
+/*?*/ 			DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 		}
 /*N*/ 		if (bValidLine)
 /*N*/ 			bValidLine = pDoc->pTab[nSrcTab]->ValidQuery(nRow, aQuery);
@@ -1138,7 +1122,7 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 							ppDataArr[nRIndex][nCIndex].Update(nVal);
 /*N*/ 						}
 /*N*/ 						else
-/*?*/ 						{DBG_BF_ASSERT(0, "STRIP");} //STRIP001 	ppDataArr[nRIndex][nCIndex].UpdateNoVal();		// nur nCount
+/*?*/ 						{DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 					}
 /*N*/ 				}
 /*N*/ 			}
@@ -1208,11 +1192,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*?*/ 			else
 /*?*/ 				nColLines += (pRowList[i]->GetCount() * aRowArr[i].nFuncCount);
 /*N*/ 		}
-/*N*/ 		/*
-        // Ergebnisspalten des letzten Elements
-        if (aRowArr[nRowCount-1].nCol != PIVOT_DATA_FIELD)
-            nColLines += (pRowList[nRowCount-1]->GetCount() * aRowArr[nRowCount-1].nFuncCount);
-        */
 /*N*/ 		if (nColLines > MAXCOL)
 /*?*/ 			nDestCol2 = MAXCOL+2;	// ungueltig, 1 wird unten abgezogen
 /*N*/ 		else if (bDataAtCol)
@@ -1254,11 +1233,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*?*/ 			else
 /*?*/ 				nRowLines += (pColList[i]->GetCount() * aColArr[i].nFuncCount);
 /*N*/ 		}
-        /*
-        // Ergebniszeilen des letzten Elements
-        if (aColArr[nColCount-1].nCol != PIVOT_DATA_FIELD)
-             nRowLines += (pColList[nColCount-1]->GetCount() * aColArr[nColCount-1].nFuncCount);
-         */
 /*N*/ 		if (nRowLines > MAXROW)
 /*?*/ 			nDestRow2 = MAXROW+2;	// ungueltig, 1 wird unten abgezogen
 /*N*/ 		else if (!bDataAtCol)
@@ -1288,10 +1262,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ 	}
 /*N*/ }
 
-
-
-
-
 /*N*/ USHORT ScPivot::GetCategoryRow( USHORT nCol, USHORT nRow )
 /*N*/ {
 /*N*/ 	USHORT nMinRow = nSrcRow1;
@@ -1309,5 +1279,6 @@ static const USHORT nFuncMaskArr[PIVOT_MAXFUNC+1] =
 /*N*/ }
 
 
-
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
