@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,6 +29,8 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
 
+#include <bf_svtools/bf_solar.h>
+
 #include <tools/inetmime.hxx>
 
 #include <adrparse.hxx>
@@ -168,8 +170,8 @@ inline void SvAddressParser_Impl::addTokenToRealName()
         if (!m_pRealNameBegin)
             m_pRealNameBegin = m_pRealNameContentBegin = m_pCurTokenBegin;
         else if (m_pRealNameEnd < m_pCurTokenBegin - 1
-                 || m_pRealNameEnd == m_pCurTokenBegin - 1
-                    && *m_pRealNameEnd != ' ')
+                 || (m_pRealNameEnd == m_pCurTokenBegin - 1
+                    && *m_pRealNameEnd != ' '))
             m_bRealNameReparse = true;
         m_pRealNameEnd = m_pRealNameContentEnd = m_pCurTokenEnd;
     }
@@ -491,6 +493,7 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                     addTokenToAddrSpec(ELEMENT_ITEM);
                 }
                 if (!m_bRealNameFinished && m_eState != AFTER_LESS)
+                {
                     if (m_bCurTokenReparse)
                     {
                         if (!m_pRealNameBegin)
@@ -512,16 +515,19 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                         m_pRealNameEnd = m_pCurTokenEnd;
                         m_bRealNameReparse = true;
                     }
+                }
                 m_eType = TOKEN_ATOM;
                 break;
 
             case TOKEN_DOMAIN:
                 if (m_pAddrSpec->m_eLastElem != ELEMENT_END)
+                {
                     if (m_pAddrSpec->m_bAtFound
                         && m_pAddrSpec->m_eLastElem == ELEMENT_DELIM)
                         addTokenToAddrSpec(ELEMENT_ITEM);
                     else
                         m_pAddrSpec->reset();
+                }
                 addTokenToRealName();
                 m_eType = TOKEN_ATOM;
                 break;
@@ -599,6 +605,7 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
 
             case '@':
                 if (m_pAddrSpec->m_eLastElem != ELEMENT_END)
+                {
                     if (!m_pAddrSpec->m_bAtFound
                         && m_pAddrSpec->m_eLastElem == ELEMENT_ITEM)
                     {
@@ -607,6 +614,7 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                     }
                     else
                         m_pAddrSpec->reset();
+                }
                 addTokenToRealName();
                 break;
 
@@ -624,8 +632,8 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                 else
                 {
                     m_pAddrSpec = m_aInnerAddrSpec.isValid()
-                                  || !m_aOuterAddrSpec.isValid()
-                                         && m_aInnerAddrSpec.isPoorlyValid() ?
+                                  || (!m_aOuterAddrSpec.isValid()
+                                         && m_aInnerAddrSpec.isPoorlyValid()) ?
                                       &m_aInnerAddrSpec :
                                   m_aOuterAddrSpec.isPoorlyValid() ?
                                       &m_aOuterAddrSpec : 0;
@@ -653,11 +661,11 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                         }
                         UniString aTheRealName;
                         if (!m_pRealNameBegin
-                            || m_pAddrSpec == &m_aOuterAddrSpec
+                            || (m_pAddrSpec == &m_aOuterAddrSpec
                                && m_pRealNameBegin
                                       == m_aOuterAddrSpec.m_pBegin
                                && m_pRealNameEnd == m_aOuterAddrSpec.m_pEnd
-                               && m_pFirstCommentBegin)
+                               && m_pFirstCommentBegin))
                             if (!m_pFirstCommentBegin)
                                 aTheRealName = aTheAddrSpec;
                             else if (m_bFirstCommentReparse)
@@ -693,10 +701,10 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
                                         nLen);
                         }
                         if (pParser->m_bHasFirst)
-                            pParser->m_aRest.Insert(new SvAddressEntry_Impl(
+                            pParser->m_aRest.push_back(new SvAddressEntry_Impl(
                                                             aTheAddrSpec,
-                                                            aTheRealName),
-                                                    LIST_APPEND);
+                                                            aTheRealName)
+                                                      );
                         else
                         {
                             pParser->m_bHasFirst = true;
@@ -737,10 +745,12 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
 
             case '.':
                 if (m_pAddrSpec->m_eLastElem != ELEMENT_END)
+                {
                     if (m_pAddrSpec->m_eLastElem != ELEMENT_DELIM)
                         addTokenToAddrSpec(ELEMENT_DELIM);
                     else
                         m_pAddrSpec->reset();
+                }
                 addTokenToRealName();
                 break;
 
@@ -759,14 +769,15 @@ SvAddressParser_Impl::SvAddressParser_Impl(SvAddressParser * pParser,
 
 SvAddressParser::SvAddressParser(UniString const & rInput): m_bHasFirst(false)
 {
-    SvAddressParser_Impl(this, rInput);
+    SvAddressParser_Impl aDoParse(this, rInput);
 }
 
 //============================================================================
 SvAddressParser::~SvAddressParser()
 {
-    for (ULONG i = m_aRest.Count(); i != 0;)
-        delete m_aRest.Remove(--i);
+    for ( size_t i = m_aRest.size(); i > 0; )
+        delete m_aRest[ --i ];
+    m_aRest.clear();
 }
 
 }
