@@ -136,9 +136,9 @@ namespace binfilter {
 /*N*/ void SwTxtAdjuster::CalcNewBlock( SwLineLayout *pCurr,
 /*N*/ 								  const SwLinePortion *pStopAt, SwTwips nReal )
 /*N*/ {
-/*N*/ 	ASSERT( GetInfo().IsMulti() || SVX_ADJUST_BLOCK == GetAdjust(),
+/*N*/ 	OSL_ENSURE( GetInfo().IsMulti() || SVX_ADJUST_BLOCK == GetAdjust(),
 /*N*/ 			"CalcNewBlock: Why?" );
-/*N*/ 	ASSERT( pCurr->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
+/*N*/ 	OSL_ENSURE( pCurr->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
 /*N*/ 
 /*N*/ 	pCurr->InitSpaceAdd();
 /*N*/ 	MSHORT nNull = 0;
@@ -162,7 +162,7 @@ namespace binfilter {
 /*N*/ 		if ( pPos->InTxtGrp() )
 /*N*/ 			nGluePortion += ((SwTxtPortion*)pPos)->GetSpaceCnt( GetInfo(), nCharCnt );
 /*N*/ 		else if( pPos->IsMultiPortion() )
-                {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 /*N*/ 		{
+                {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
 /*N*/ 		if( pPos->InGlueGrp() )
 /*N*/ 		{
@@ -356,7 +356,7 @@ namespace binfilter {
 
 /*N*/ void SwTxtAdjuster::CalcAdjLine( SwLineLayout *pCurr )
 /*N*/ {
-/*N*/ 	ASSERT( pCurr->IsFormatAdj(), "CalcAdjLine: Why?" );
+/*N*/ 	OSL_ENSURE( pCurr->IsFormatAdj(), "CalcAdjLine: Why?" );
 /*N*/ 
 /*N*/ 	pCurr->SetFormatAdj(sal_False);
 /*N*/ 
@@ -427,17 +427,15 @@ namespace binfilter {
 /*N*/ 
 /*N*/     SwRect aLineVert( rCurrRect );
 /*N*/     if ( GetTxtFrm()->IsRightToLeft() )
-/*?*/         {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 GetTxtFrm()->SwitchLTRtoRTL( aLineVert );
-/*N*/     if ( GetTxtFrm()->IsVertical() )
-/*?*/         GetTxtFrm()->SwitchHorizontalToVertical( aLineVert );
+/*?*/         {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/ 
 /*N*/ 	// aFlyRect ist dokumentglobal !
 /*N*/     SwRect aFlyRect( aTxtFly.GetFrm( aLineVert ) );
 /*N*/ 
 /*N*/     if ( GetTxtFrm()->IsRightToLeft() )
-/*?*/         {DBG_BF_ASSERT(0, "STRIP");} //STRIP001 GetTxtFrm()->SwitchRTLtoLTR( aFlyRect );
+/*?*/         {DBG_BF_ASSERT(0, "STRIP");}
 /*N*/     if ( GetTxtFrm()->IsVertical() )
-/*?*/         {DBG_BF_ASSERT(0, "STRIP"); }//STRIP001 GetTxtFrm()->SwitchVerticalToHorizontal( aFlyRect );
+/*?*/         {DBG_BF_ASSERT(0, "STRIP"); }
 /*N*/ 
 /*N*/ 	// Wenn ein Frame ueberlappt, wird eine Portion eroeffnet.
 /*N*/ 	if( aFlyRect.HasArea() )
