@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,77 +26,36 @@
  *
  ************************************************************************/
 
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
 
-#ifndef _VOS_MUTEX_HXX_ //autogen
-#include <vos/mutex.hxx>
-#endif
-#ifndef _SV_SVAPP_HXX //autogen
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
-#endif
-#ifndef _PAGEDESC_HXX //autogen
 #include <pagedesc.hxx>
-#endif
 #include "poolfmt.hxx"
-#ifndef _REDLINE_HXX
 #include <redline.hxx>
-#endif
-#ifndef _SECTION_HXX
 #include <section.hxx>
-#endif
-#ifndef _UNOPRNMS_HXX
 #include <unoprnms.hxx>
-#endif
 
-#ifndef _ERRHDL_HXX
-#include <errhdl.hxx>
-#endif
+#include <osl/diagnose.h>
 
-#ifndef _UNOOBJ_HXX
 #include <unoobj.hxx>
-#endif
-#ifndef _UNOCOLL_HXX
 #include <unocoll.hxx>
-#endif
-#ifndef _UNOMAP_HXX
 #include <unomap.hxx>
-#endif
-#ifndef _UNOCRSR_HXX
 #include <unocrsr.hxx>
-#endif
-#ifndef _UNOOBJ_HXX
 #include <unoobj.hxx>
-#endif
-#ifndef _UNOREDLINE_HXX
 #include <unoredline.hxx>
-#endif
 
-#ifndef _HORIORNT_HXX
 #include <horiornt.hxx>
-#endif
 
-#ifndef _DOC_HXX //autogen
 #include <doc.hxx>
-#endif
-#ifndef _DOCARY_HXX
 #include <docary.hxx>
-#endif
-#ifndef _RTL_UUID_H_
 #include <rtl/uuid.h>
-#endif
 
-#ifndef _RTL_USTRBUF_HXX_
 #include <rtl/ustrbuf.hxx>
-#endif
-#ifndef _COM_SUN_STAR_UTIL_DATETIME_HPP_
 #include <com/sun/star/util/DateTime.hpp>
-#endif
-#ifndef _COM_SUN_STAR_TEXT_XTEXTTABLE_HPP_
 #include <com/sun/star/text/XTextTable.hpp>
-#endif
 namespace binfilter {
 
 using namespace ::com::sun::star;
@@ -104,27 +64,21 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::text;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::beans;
-using namespace ::rtl;
 
+using rtl::OUString;
+using rtl::OUStringBuffer;
 
-/* ---------------------------------------------------------------------------
-
- ---------------------------------------------------------------------------*/
-SwXRedlineText::SwXRedlineText(SwDoc* pDoc, SwNodeIndex aIndex) :
-    SwXText(pDoc, CURSOR_REDLINE),
+SwXRedlineText::SwXRedlineText(SwDoc* pInDoc, SwNodeIndex aIndex) :
+    SwXText(pInDoc, CURSOR_REDLINE),
     aNodeIndex(aIndex)
 {
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 const SwStartNode* SwXRedlineText::GetStartNode() const
 {
     return aNodeIndex.GetNode().GetStartNode();
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Any SwXRedlineText::queryInterface( const Type& rType )
     throw(RuntimeException)
 {
@@ -147,9 +101,7 @@ Any SwXRedlineText::queryInterface( const Type& rType )
 
     return aRet;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence<Type> SwXRedlineText::getTypes()
     throw(RuntimeException)
 {
@@ -163,13 +115,11 @@ Sequence<Type> SwXRedlineText::getTypes()
 
     return aTypes;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence<sal_Int8> SwXRedlineText::getImplementationId()
     throw(RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     static Sequence< sal_Int8 > aId( 16 );
     static sal_Bool bInit = sal_False;
     if(!bInit)
@@ -179,13 +129,11 @@ Sequence<sal_Int8> SwXRedlineText::getImplementationId()
     }
     return aId;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference<XTextCursor> SwXRedlineText::createTextCursor(void)
     throw( RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     SwPosition aPos(aNodeIndex);
     SwXTextCursor* pCrsr = new SwXTextCursor(this, aPos, CURSOR_REDLINE,
@@ -223,9 +171,7 @@ Reference<XTextCursor> SwXRedlineText::createTextCursor(void)
 
     return (XWordCursor*)pCrsr;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference<XTextCursor> SwXRedlineText::createTextCursorByRange(
     const Reference<XTextRange> & aTextRange)
         throw( RuntimeException )
@@ -235,53 +181,39 @@ Reference<XTextCursor> SwXRedlineText::createTextCursorByRange(
     xCursor->gotoRange(aTextRange->getEnd(), sal_True);
     return xCursor;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference<XEnumeration> SwXRedlineText::createEnumeration(void)
     throw( RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     SwPaM aPam(aNodeIndex);
     aPam.Move(fnMoveForward, fnGoNode);
     return new SwXParagraphEnumeration(this, *aPam.Start(), CURSOR_REDLINE);
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Type SwXRedlineText::getElementType(  ) throw(RuntimeException)
 {
     return ::getCppuType((uno::Reference<XTextRange>*)0);
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwXRedlineText::hasElements(  ) throw(RuntimeException)
 {
     return sal_True; 	// we always have a content index
 }
-/* -----------------------------19.12.00 11:36--------------------------------
 
- ---------------------------------------------------------------------------*/
 SwXRedlinePortion::SwXRedlinePortion(	const SwRedline* pRed,
                         const SwUnoCrsr* pPortionCrsr,
                         Reference< XText >  xParent, BOOL bStart) :
     SwXTextPortion(pPortionCrsr, xParent, bStart ? PORTION_REDLINE_START : PORTION_REDLINE_END),
-//	SwXText(pPortionCrsr->GetDoc(), CURSOR_REDLINE),
-//	SwXRedlineText(pPortionCrsr->GetDoc(), *pRed->GetContentIdx()),
     pRedline(pRed)
 {
     SetCollapsed(!pRedline->HasMark());
 }
-/*-- 19.12.00 11:37:24---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXRedlinePortion::~SwXRedlinePortion()
 {
 }
-/* -----------------------------19.12.00 11:46--------------------------------
 
- ---------------------------------------------------------------------------*/
 util::DateTime lcl_DateTimeToUno(const DateTime& rDT)
 {
     util::DateTime aRetDT;
@@ -294,7 +226,7 @@ util::DateTime lcl_DateTimeToUno(const DateTime& rDT)
     aRetDT.HundredthSeconds = rDT.Get100Sec();
     return aRetDT;
 }
-// ---------------------------------------------------------------------------
+
 OUString lcl_RedlineTypeToOUString(SwRedlineType eType)
 {
     OUString sRet;
@@ -308,7 +240,7 @@ OUString lcl_RedlineTypeToOUString(SwRedlineType eType)
     }
     return sRet;
 }
-// ---------------------------------------------------------------------------
+
 Sequence<PropertyValue> lcl_GetSuccessorProperties(const SwRedline& rRedline)
 {
     Sequence<PropertyValue> aValues(4);
@@ -330,11 +262,11 @@ Sequence<PropertyValue> lcl_GetSuccessorProperties(const SwRedline& rRedline)
     }
     return aValues;
 }
-// ---------------------------------------------------------------------------
+
 Any SwXRedlinePortion::getPropertyValue( const OUString& rPropertyName )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Validate();
     Any aRet;
     if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_TEXT)))
@@ -361,9 +293,7 @@ Any SwXRedlinePortion::getPropertyValue( const OUString& rPropertyName )
     }
     return aRet;
 }
-/* -----------------------------19.12.00 15:16--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwXRedlinePortion::Validate() throw( RuntimeException )
 {
     SwUnoCrsr* pUnoCrsr = GetCrsr();
@@ -378,12 +308,10 @@ void SwXRedlinePortion::Validate() throw( RuntimeException )
     if(!bFound)
         throw RuntimeException();
 }
-/* -----------------------------21.03.00 15:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Sequence< sal_Int8 > SAL_CALL SwXRedlinePortion::getImplementationId(  ) throw(uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     static Sequence< sal_Int8 > aId( 16 );
     static sal_Bool bInit = sal_False;
     if(!bInit)
@@ -393,9 +321,7 @@ uno::Sequence< sal_Int8 > SAL_CALL SwXRedlinePortion::getImplementationId(  ) th
     }
     return aId;
 }
-/* -----------------------------11.01.01 16:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 Any  SwXRedlinePortion::GetPropertyValue( const OUString& rPropertyName, const SwRedline& rRedline ) throw()
 {
     Any aRet;
@@ -435,9 +361,7 @@ Any  SwXRedlinePortion::GetPropertyValue( const OUString& rPropertyName, const S
     }
     return aRet;
 }
-/* -----------------------------11.01.01 11:22--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< PropertyValue > SwXRedlinePortion::CreateRedlineProperties(
     const SwRedline& rRedline, sal_Bool bIsStart ) throw()
 {
@@ -490,49 +414,41 @@ Sequence< PropertyValue > SwXRedlinePortion::CreateRedlineProperties(
     aRet.realloc(nPropIdx);
     return aRet;
 }
-/*-- 11.01.01 17:06:07---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 TYPEINIT1(SwXRedline, SwClient);
 SwXRedline::SwXRedline(SwRedline& rRedline, SwDoc& rDoc) :
-    pDoc(&rDoc),
     SwXText(&rDoc, CURSOR_REDLINE),
+    pDoc(&rDoc),
     pRedline(&rRedline)
 {
     pDoc->GetPageDescFromPool(RES_POOLPAGE_STANDARD)->Add(this);
 }
-/*-- 11.01.01 17:06:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXRedline::~SwXRedline()
 {
 }
-/*-- 11.01.01 17:06:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XPropertySetInfo > SwXRedline::getPropertySetInfo(  ) throw(RuntimeException)
 {
     static uno::Reference< beans::XPropertySetInfo >  xRef =
         SfxItemPropertySet(aSwMapProvider.GetPropertyMap(PROPERTY_MAP_REDLINE)).getPropertySetInfo();
     return xRef;
 }
-/*-- 11.01.01 17:06:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::setPropertyValue( const OUString& rPropertyName, const Any& aValue )
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException,
         WrappedTargetException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(!pDoc)
         throw RuntimeException();
     if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_AUTHOR)))
     {
-        DBG_ERROR("currently not available");
+        OSL_FAIL("currently not available");
     }
     else if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_DATE_TIME)))
     {
-        DBG_ERROR("currently not available");
+        OSL_FAIL("currently not available");
     }
     else if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_COMMENT)))
     {
@@ -541,27 +457,25 @@ void SwXRedline::setPropertyValue( const OUString& rPropertyName, const Any& aVa
     }
     else if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_TYPE)))
     {
-        DBG_ERROR("currently not available");
+        OSL_FAIL("currently not available");
         OUString sTmp; aValue >>= sTmp;
         if(!sTmp.getLength())
             throw IllegalArgumentException();
     }
     else if(rPropertyName.equalsAsciiL(SW_PROP_NAME(UNO_NAME_REDLINE_SUCCESSOR_DATA)))
     {
-        DBG_ERROR("currently not available");
+        OSL_FAIL("currently not available");
     }
     else
     {
         throw IllegalArgumentException();
     }
 }
-/*-- 11.01.01 17:06:08---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Any SwXRedline::getPropertyValue( const OUString& rPropertyName )
     throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(!pDoc)
         throw RuntimeException();
     Any aRet;
@@ -600,14 +514,13 @@ Any SwXRedline::getPropertyValue( const OUString& rPropertyName )
                     pPoint = pRedline->GetMark();
                 SwPaM aTmp(*pPoint);
                 Reference<XText> xTmpParent;
-//				Reference< XTextRange > xRange = SwXTextRange::createTextRangeFromPaM(aTmp);
                 Reference<XTextRange>xRange =
                     SwXTextRange::CreateTextRangeFromPosition( pDoc, *pPoint, 0 );
                 xRet = xRange.get();
             }
             break;
             default:
-                DBG_ERROR("illegal node type");
+                OSL_FAIL("illegal node type");
         }
         aRet <<= xRet;
     }
@@ -629,42 +542,32 @@ Any SwXRedline::getPropertyValue( const OUString& rPropertyName )
         aRet = SwXRedlinePortion::GetPropertyValue(rPropertyName, *pRedline);
     return aRet;
 }
-/*-- 11.01.01 17:06:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::addPropertyChangeListener(
-    const OUString& aPropertyName,
-    const Reference< XPropertyChangeListener >& xListener )
+    const OUString& /*aPropertyName*/,
+    const Reference< XPropertyChangeListener >& /*xListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.01.01 17:06:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::removePropertyChangeListener(
-    const OUString& aPropertyName, const Reference< XPropertyChangeListener >& aListener )
+    const OUString& /*aPropertyName*/, const Reference< XPropertyChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.01.01 17:06:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::addVetoableChangeListener(
-    const OUString& PropertyName, const Reference< XVetoableChangeListener >& aListener )
+    const OUString& /*PropertyName*/, const Reference< XVetoableChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.01.01 17:06:09---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::removeVetoableChangeListener(
-    const OUString& PropertyName, const Reference< XVetoableChangeListener >& aListener )
+    const OUString& /*PropertyName*/, const Reference< XVetoableChangeListener >& /*aListener*/ )
         throw(UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
 }
-/*-- 11.01.01 17:06:10---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void SwXRedline::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
 {
     ClientModify(this, pOld, pNew);
@@ -674,12 +577,10 @@ void SwXRedline::Modify( SfxPoolItem *pOld, SfxPoolItem *pNew)
         pRedline = 0;
     }
 }
-/*-- 19.12.00 11:37:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XEnumeration >  SwXRedline::createEnumeration(void) throw( RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     Reference< XEnumeration > xRet;
     if(!pDoc)
         throw RuntimeException();
@@ -693,28 +594,22 @@ Reference< XEnumeration >  SwXRedline::createEnumeration(void) throw( RuntimeExc
     }
     return xRet;
 }
-/* -----------------------------19.12.00 12:34--------------------------------
 
- ---------------------------------------------------------------------------*/
 uno::Type SwXRedline::getElementType(  ) throw(RuntimeException)
 {
     return ::getCppuType((uno::Reference<XTextRange>*)0);
 }
-/* -----------------------------19.12.00 12:34--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwXRedline::hasElements(  ) throw(RuntimeException)
 {
     if(!pDoc)
         throw RuntimeException();
     return 0 != pRedline->GetContentIdx();
 }
-/* -----------------------------19.12.00 15:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XTextCursor >  SwXRedline::createTextCursor(void) throw( RuntimeException )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(!pDoc)
         throw RuntimeException();
 
@@ -746,19 +641,15 @@ Reference< XTextCursor >  SwXRedline::createTextCursor(void) throw( RuntimeExcep
     }
     return xRet;
 }
-/* -----------------------------19.12.00 15:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 Reference< XTextCursor >  SwXRedline::createTextCursorByRange(
-    const Reference< XTextRange > & aTextPosition)
+    const Reference< XTextRange > & /*aTextPosition*/)
         throw( RuntimeException )
 {
     throw RuntimeException();
     return Reference< XTextCursor >  ();
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Any SwXRedline::queryInterface( const uno::Type& rType )
     throw(RuntimeException)
 {
@@ -769,9 +660,7 @@ Any SwXRedline::queryInterface( const uno::Type& rType )
     }
     return aRet;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence<Type> SwXRedline::getTypes()
     throw(RuntimeException)
 {
@@ -785,13 +674,11 @@ Sequence<Type> SwXRedline::getTypes()
         pTypes[nCurType++] = pBaseTypes[nType];
     return aTypes;
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence<sal_Int8> SwXRedline::getImplementationId()
     throw(RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     static Sequence< sal_Int8 > aId( 16 );
     static sal_Bool bInit = sal_False;
     if(!bInit)
@@ -803,3 +690,5 @@ Sequence<sal_Int8> SwXRedline::getImplementationId()
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
